@@ -27,6 +27,8 @@ sub import {
 use constant is_embedded => 1;
 use constant dbd => 'DBD::FirebirdEmbedded';
 
+use DBD::FirebirdEmbedded;
+
 sub check_credentials {
     # this is embedded, nothing to check, we don't need credentials
 }
@@ -36,7 +38,8 @@ sub read_cached_configs {
     $self->SUPER::read_cached_configs;
 
     # this is embedded, no server involved
-    $ENV{FIREBIRD} = $ENV{FIREBIRD_LOCK} = '.';
+    $ENV{FIREBIRD} = $ENV{FIREBIRD_LOCK} = '.'
+        unless DBD::FirebirdEmbedded->fb_api_ver => 30;
     # no authentication either
     delete $ENV{ISC_USER};
     delete $ENV{ISC_PASSWORD};
@@ -47,6 +50,10 @@ sub read_cached_configs {
     delete $self->{pass};
     delete $self->{host};
 
+    if (DBD::FirebirdEmbedded->fb_api_ver >= 30) {
+        $self->{user} = 'SYSDBA';
+        $self->{pass} = 'any';
+    }
     $self->{tdsn} = $self->get_dsn;
     $self->{path} = $self->get_path;
 }
